@@ -1,5 +1,7 @@
 
 // ---------- Meta -------------
+typedef unsigned long BITMASK;
+
 int read_jpeg_info(
     const char *srcfile,
     int *block_dims,
@@ -8,13 +10,12 @@ int read_jpeg_info(
     int *samp_factor,
     int *jpeg_color_space,
     int *marker_lengths,
-    int *mark_types
-);
+    int *mark_types,
+    BITMASK *flags);
 
 int read_jpeg_markers(
     const char *srcfile,
-    unsigned char *markers
-);
+    unsigned char *markers);
 
 // ----------- DCT -------------
 int read_jpeg_dct(
@@ -22,8 +23,8 @@ int read_jpeg_dct(
     short *Y,
     short *Cb,
     short *Cr,
-    unsigned short *qt
-);
+    unsigned short *qt,
+    unsigned char *quant_tbl_no);
 int write_jpeg_dct(
     const char *srcfile,
     const char *dstfile,
@@ -39,21 +40,18 @@ int write_jpeg_dct(
     int num_markers,
     int *marker_types,
     int *marker_lengths,
-    unsigned char *markers
-);
+    unsigned char *markers);
 
 // ----------- RGB -------------
-typedef unsigned long BITMASK;
 int read_jpeg_spatial(
     const char *srcfile,
     unsigned char *rgb,
-    unsigned char *colormap, // colormap used
+    unsigned char *colormap,    // colormap used
     unsigned char *in_colormap, // colormap to use
     int out_color_space,
     int dither_mode,
     int dct_method,
-    BITMASK flags
-);
+    BITMASK flags);
 
 int write_jpeg_spatial(
     const char *dstfile,
@@ -70,8 +68,7 @@ int write_jpeg_spatial(
     int *marker_types,
     int *marker_lengths,
     unsigned char *markers,
-    BITMASK flags
-);
+    BITMASK flags);
 
-//int jpeg_lib_version(void) { return JPEG_LIB_VERSION; }
+// int jpeg_lib_version(void) { return JPEG_LIB_VERSION; }
 int print_jpeg_params(const char *srcfile);
